/**
 * Update dependencies.
 * @memberof apeman-dev-commons-updating/lib
 * @function updateDependencies
 * @param {options} [options] - Optional settings.
 * @param {string} [options.pkgPath] - Package.json path.
 * @param {function} [callback] - callback when done.
 */

"use strict";

var apeUpdating = require('ape-updating'),
    argx = require('argx'),
    async = require('async'),
    colorprint = require('colorprint');

/** @lends updateDependencies */
function updateDependencies(options, callback) {
    var args = argx(arguments);
    callback = args.pop('function') || argx.noop;
    options = args.pop('object') || {};
    async.series([
        function (callback) {
            colorprint.info('Updating dependencies started...');
            callback(null);
        },
        function (callback) {
            apeUpdating.updateDependencies(options, callback)
        },
        function (callback) {
            colorprint.info('...updating dependencies done!');
            callback(null);
        }
    ], callback);
}


module.exports = updateDependencies;
